#!/usr/bin/env python3

WELL_KNOWN = "https://auth.cern.ch/auth/realms/cern/.well-known/openid-configuration"
AUTH_ENDPOINT = "https://auth.cern.ch/auth/realms/cern/protocol/openid-connect/auth"
TOKEN_ENDPOINT = "https://auth.cern.ch/auth/realms/cern/protocol/openid-connect/token"
CLIENT_ID = "uhepp"
REDIRECT_URI = "https://uhepp.org/login/cb"
SECRETS = "client_secret"

import requests
import yaml
from uuid import uuid4
import jwt
from urllib.parse import urlencode, urlparse, parse_qs
from requests.auth import HTTPBasicAuth

def build_url(path, query={}):
    """Build url by encoding query parameters"""
    return path + "?" + urlencode(query)

def get_id_token():
    """Perform a auth action and return the id and access token"""
    state = str(uuid4())

    query = {"response_type": "code",
             "scope": "openid",
             "client_id": CLIENT_ID,
             "state": state,
             "redirect_uri": REDIRECT_URI}
    print("Go to " + build_url(AUTH_ENDPOINT, query))

    call_back = input("Enter redirected url: ")
    call_back = urlparse(call_back)
    cb_query = parse_qs(call_back.query)

    with open(SECRETS) as secret_file:
        auth = yaml.load(secret_file)
    auth = HTTPBasicAuth(auth["id"], auth["secret"])

    data = {"grant_type": "authorization_code",
            "code": cb_query["code"],
            "redirect_uri": REDIRECT_URI}
    response = requests.post(TOKEN_ENDPOINT, data=data, auth=auth)
    id_token_str = response.json()["id_token"]

    return jwt.decode(id_token_str, verify=False)
