import { use, assert, expect } from 'chai';
import chaiAlmost from 'chai-almost';
import { sumBase, sumStat } from "../src/helpers/uhepp.js";

use(chaiAlmost())

const toy_yield = {
  "process_a": {
    "base": [ 0,  1,  2,  3,  4,  5],
    "stat": [0.1, 0.1, 0.1, 0.1, 0.1]
  },
  "process_b": {
    "base": [10, 12, 14, 16, 18, 20],
    "stat": [1.0, 1.2, 1.4, 1.6, 1.8, 2.0]
  },
  "process_c": {
    "base": [ 4,  4,  -5,  -5,  -6,  5],
    "stat": [ 0.4, 0.4, 0.5, 0.5, 0.6, 0.6]
  }
}

describe("sumBase", () => {
    it("should return 0 if the yield object is empty", () => {
        const sum = sumBase({}, ["process_a", "process_b"])
        assert.equal(sum, 0);
    })
    it("should return 0 if the yield non of the processes are present", () => {
        const sum = sumBase(toy_yield, ["process_d", "process_e"])
        assert.equal(sum, 0);
    })
    it("should return the total sum of the single process found in the object", () => {
        const sum = sumBase(toy_yield, ["process_a", "process_e"])
        assert.equal(sum, 15);
    })
    it("should return the total sum of all process", () => {
        const sum = sumBase(toy_yield, ["process_a", "process_c"])
        assert.equal(sum, 12);
    })
    it("should return 0 if process name list is empty", () => {
        const sum = sumBase(toy_yield, [])
        assert.equal(sum, 0);
    })
    it("should return 0 if process name list and object are empty", () => {
        const sum = sumBase({}, [])
        assert.equal(sum, 0);
    })

    it("should return 0 if the yield object is empty for bin=2", () => {
        const sum = sumBase({}, ["process_a", "process_b"], 2)
        assert.equal(sum, 0);
    })
    it("should return 0 if the yield non of the processes are present for and bin=2", () => {
        const sum = sumBase(toy_yield, ["process_d", "process_e"], 2)
        assert.equal(sum, 0);
    })
    it("should return the sum of the single process found in the object for bin=2", () => {
        const sum = sumBase(toy_yield, ["process_a", "process_e"], 2)
        assert.equal(sum, 2);
    })
    it("should return the sum of all process for bin=2", () => {
        const sum = sumBase(toy_yield, ["process_a", "process_c"], 2)
        assert.equal(sum, -3);
    })
    it("should return 0 if process name list is empty for bin=2", () => {
        const sum = sumBase(toy_yield, [], 2)
        assert.equal(sum, 0);
    })
    it("should return 0 if process name list and object are empty for bin=2", () => {
        const sum = sumBase({}, [], 2)
        assert.equal(sum, 0);
    })
});

describe("sumStat", () => {
    it("should return 0 if the yield object is empty", () => {
        const sum = sumStat({}, ["process_a", "process_b"])
        assert.equal(sum, 0);
    })
    it("should return 0 if the yield non of the processes are present", () => {
        const sum = sumStat(toy_yield, ["process_d", "process_e"])
        assert.equal(sum, 0);
    })
    it("should return the total sum of the single process found in the object", () => {
        const sum = sumStat(toy_yield, ["process_a", "process_e"])
        expect(sum * sum).to.almost.equal(0.05);
    })
    it("should return the total sum of all process", () => {
        const sum = sumStat(toy_yield, ["process_a", "process_c"])
        expect(sum * sum).to.almost.equal(1.59);
    })
    it("should return 0 if process name list is empty", () => {
        const sum = sumStat(toy_yield, [])
        assert.equal(sum, 0);
    })
    it("should return 0 if process name list and object are empty", () => {
        const sum = sumStat({}, [])
        assert.equal(sum, 0);
    })

    it("should return 0 if the yield object is empty for bin=2", () => {
        const sum = sumStat({}, ["process_a", "process_b"], 2)
        assert.equal(sum, 0);
    })
    it("should return 0 if the yield non of the processes are present for and bin=2", () => {
        const sum = sumStat(toy_yield, ["process_d", "process_e"], 2)
        assert.equal(sum, 0);
    })
    it("should return the sum of the single process found in the object for bin=2", () => {
        const sum = sumStat(toy_yield, ["process_a", "process_e"], 2)
        expect(sum).to.almost.equal(0.1);
    })
    it("should return the sum of all process for bin=2", () => {
        const sum = sumStat(toy_yield, ["process_a", "process_c"], 2)
        assert.equal(sum * sum, 0.26);
    })
    it("should return 0 if process name list is empty for bin=2", () => {
        const sum = sumStat(toy_yield, [], 2)
        assert.equal(sum, 0);
    })
    it("should return 0 if process name list and object are empty for bin=2", () => {
        const sum = sumStat({}, [], 2)
        assert.equal(sum, 0);
    })
});
